.brightcove_widget_refresh {
    margin-left: 10px;
}
.brightcove_widget_refresh span {
    margin-right: 3px;
}

.brightcove_widget table {
    background-color: #dbdbdb;
    margin-top: 10px;
    width: 460px;
}
.brightcove_widget table .label {
    font-weight: bold;
    min-width: 120px;
    text-align: right;
}
