<object id="myExperience{{ player_id }}" class="BrightcoveExperience">
    <param name="bgcolor" value="{{ bgcolor }}" />
    <param name="width" value="{{ width }}" />
    <param name="height" value="{{ height }}" />
    <param name="autoStart" value="false" />
    <param name="playerID" value="{{ playerID }}" />
    <param name="playerKey" value="{{ playerKey }}" />
    <param name="isVid" value="{{ isVid }}" />
    <param name="isUI" value="{{ isUI }}" />
    <param name="dynamicStreaming" value="{{ dynamicStreaming }}" />

    <param name="@videoPlayer" value="{{ player_id }}" />
</object>
